@@ -11,7 +11,7 @@ except:
         from notification_manager_api.api.src.enumeration.NotificationStatus import NotificationStatus
         from notification_manager_api.api.src.enumeration.NotificationDestiny import NotificationDestiny
     except Exception as exception:
-        log.warning(log.warning, 'There are most likely an issue related to queue-manager-api dependencies imports', exception=exception)
+        log.warning(log.warning, 'There is most likely an issue related to queue-manager-api dependencies imports', exception=exception)
         from notification_manager_api import NotificationSeverity
         from notification_manager_api import NotificationStatus
         from notification_manager_api import NotificationDestiny
